/**
 * GMyth Library
 *
 * @file gmyth/gmyth_recorder.h
 * 
 * @brief <p> GMythRecorder class defines functions for playing live tv.
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Hallyson Luiz de Morais Melo <hallyson.melo@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_RECORDER_H__
#define __GMYTH_RECORDER_H__

#include <glib-object.h>

#include "gmyth_socket.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <netdb.h>
#include <sys/socket.h>
#include <unistd.h>

G_BEGIN_DECLS

#define GMYTH_RECORDER_TYPE               (gmyth_recorder_get_type ())
#define GMYTH_RECORDER(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_RECORDER_TYPE, GMythRecorder))
#define GMYTH_RECORDER_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_RECORDER_TYPE, GMythRecorderClass))
#define IS_GMYTH_RECORDER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_RECORDER_TYPE))
#define IS_GMYTH_RECORDER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_RECORDER_TYPE))
#define GMYTH_RECORDER_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_RECORDER_TYPE, GMythRecorderClass))


typedef struct _GMythRecorder         GMythRecorder;
typedef struct _GMythRecorderClass    GMythRecorderClass;

struct _GMythRecorderClass
{
  GObjectClass parent_class;

  /* callbacks */
  /* no one for now */
};

struct _GMythRecorder
{
    GObject parent;

    /* socket descriptor */
    GMythSocket *myth_socket;
    
    int recorder_num;
    GString *hostname;
    int port;
};


GType   gmyth_recorder_get_type   (void);

GMythRecorder* gmyth_recorder_new    (int num,
	                                     GString *hostname,
	                                     gshort port);

gboolean gmyth_recorder_setup     (GMythRecorder *recorder);
gboolean gmyth_recorder_spawntv   (GMythRecorder *recorder,
                                         GString *tvchain_id);
gboolean gmyth_recorder_stop_livetv (GMythRecorder *recorder);

gboolean gmyth_recorder_check_channel (GMythRecorder *recorder, gint channel);

gboolean gmyth_recorder_set_channel   (GMythRecorder *recorder,
                                         gint channel);

G_END_DECLS

#endif /* __GMYTH_REMOTE_ENCODER_H__ */
